@@ -193,7 +193,7 @@ gtkhtml_editor_private_init (GtkhtmlEditor *editor)
 
 	priv->builder = gtk_builder_new ();
 	/* To keep translated strings in subclasses */
-        gtk_builder_set_translation_domain (priv->builder, GETTEXT_PACKAGE);
+	gtk_builder_set_translation_domain (priv->builder, GETTEXT_PACKAGE);
 	if (!gtk_builder_add_from_file (priv->builder, filename, &error)) {
 		g_critical ("Couldn't load builder file: %s\n", error->message);
 		g_clear_error (&error);
@@ -235,6 +235,10 @@ gtkhtml_editor_private_constructed (GtkhtmlEditor *editor)
 	priv->main_toolbar = g_object_ref (widget);
 	gtk_widget_show (widget);
 
+	gtk_style_context_add_class (
+		gtk_widget_get_style_context (widget),
+		GTK_STYLE_CLASS_PRIMARY_TOOLBAR);
+
 	widget = gtkhtml_editor_get_managed_widget (editor, "/edit-toolbar");
 	gtk_toolbar_set_style (GTK_TOOLBAR (widget), GTK_TOOLBAR_BOTH_HORIZ);
 	gtk_box_pack_start (GTK_BOX (editor->vbox), widget, FALSE, FALSE, 0);
@@ -482,36 +486,6 @@ gtkhtml_editor_find_data_file (const gchar *basename)
 	return NULL;  /* never gets here */
 }
 
-gint
-gtkhtml_editor_insert_file (GtkhtmlEditor *editor,
-                            const gchar *title,
-                            GCallback response_cb)
-{
-	GtkWidget *dialog;
-	gint response;
-
-	g_return_val_if_fail (GTKHTML_IS_EDITOR (editor), GTK_RESPONSE_CANCEL);
-	g_return_val_if_fail (response_cb != NULL, GTK_RESPONSE_CANCEL);
-
-	dialog = gtk_file_chooser_dialog_new (
-		title, GTK_WINDOW (editor),
-		GTK_FILE_CHOOSER_ACTION_OPEN,
-		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-		GTK_STOCK_OPEN, GTK_RESPONSE_OK,
-		NULL);
-
-	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (dialog), FALSE);
-	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
-
-	g_signal_connect (dialog, "response", response_cb, editor);
-
-	response = gtkhtml_editor_file_chooser_dialog_run (editor, dialog);
-
-	gtk_widget_destroy (dialog);
-
-	return response;
-}
-
 GFile *
 gtkhtml_editor_run_open_dialog (GtkhtmlEditor *editor,
                                 const gchar *title,
